/*
PXNAME.C

Changes the Paradox engine UserName in WIN.INI.  Usage is "PxName [-d
Window-directory] [new-UserName]".  Without the new-UserName argument,
it will report the current UserName.  The default Windows directory,
C:\WINDOWS, may be over-ridden with the -d option.

ObjectVision 2.0 uses the Paradox engine UserName rather than the Novell
network login id for locking directories and tables.  UserName is stored
in section [Paradox Engine] in WIN.INI, and may be set via the Windows
program PXENGCFG.EXE supplied with OV.  It won't necessarily reflect who
has actually logged on to that workstation.

DOS program PXNAME.EXE may be called from a Novell 3.xx login script:
"#pxname %LOGON_NAME" (without the quotes).  Then the locks (displayed,
for instance, with the Paradox command "Tools Info Who") will more
accurately reflect who's responsible.

Bruce Wentworth September 21, 1992
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

main (int argc, char *argv[])
   {
   FILE *fin, *ftmp;
   char defdir[128]="C:\\WINDOWS\\",
        in[144], tmp[144],
        username[48],
        rec[256], *recpt, buf[256];
   int i, j, pxflag=0, modflag=0;

   username[0]=0;

   for (i=1;i<argc;i++)
      {
      if (strncmpi("-d",argv[i],2)==0)
         {
         if (strlen(argv[i])>2) strncpy(defdir,argv[i]+2,126);
         else
            {
            i++;
            if (i<argc)
               {
               strncpy(defdir,argv[i],126);
               }
            }
         defdir[126]=0;
         strupr(defdir);
         j=strlen(defdir)-1;
         if (defdir[j]!=':' && defdir[j]!='\\') strcat(defdir,"\\");
         }

      else
         {
         if (username[0]==0)
            {
            strncpy(username,argv[i],47);
            username[47]=0;
            }
         }
      }

   sprintf(in, "%sWIN.INI",defdir);
   sprintf(tmp,"%sWIN.PXN",defdir);

   fin=fopen(in, "rt");
   if (fin==0)
      {
      fprintf(stderr,"PxName: Can't open %s\n",in);
      return 1;
      }

   if (username[0]!=0)
      {
      ftmp=fopen(tmp, "wt");
      if (ftmp==0)
         {
         fprintf(stderr,"PxName: Can't open %s\n",tmp);
         return 1;
         }
      }

   recpt=fgets(rec,255,fin);
   rec[255]=0;
   while (recpt!=0)
      {
      if (rec[0]=='[') pxflag=0;
      if (strcmp(rec,"[Paradox Engine]\n")==0) pxflag=1;
      if (pxflag==1 && strncmp(rec,"UserName=",9)==0)
         {
         if (username[0]!=0)
            {
            sprintf(buf,"UserName=%s\n",username);
            if (strcmp(rec,buf)!=0)
               {
               strcpy(rec,buf);
               modflag++;
               }
            }
         else printf (&rec[9]);
         }

      if (username[0]!=0)
         {
         if (fprintf(ftmp,rec)<0)
            {
            fprintf(stderr,"PxName: Can't write to %s\n",tmp);
            fclose(fin);
            fclose(ftmp);
            return 1;
            }
         }

      recpt=fgets(rec,255,fin);
      rec[255]=0;
      }

   fclose(fin);

   if (username[0]!=0)
      {
      fclose(ftmp);

      if (modflag==0)
         {
         if (unlink(tmp)!=0)
            {
            fprintf(stderr,"PxName: Can't delete %s\n",tmp);
            return 1;
            }
         }
      else
         {
         if (unlink(in)!=0)
            {
            fprintf(stderr,"PxName: Can't delete %s\n",in);
            return 1;
            }
         if (rename(tmp,in)!=0)
            {
            fprintf(stderr,"PxName: Can't rename %s to %s\n",tmp,in);
            return 1;
            }
         }
      }

   return 0;
   }
